==> haskell-network-protocol-xmpp-0.4.8-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-network-protocol-xmpp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-protocol-xmpp
version: 0.4.8
id: network-protocol-xmpp-0.4.8-9LXhpkDE0sYCmc8XBXzy4Y
key: network-protocol-xmpp-0.4.8-9LXhpkDE0sYCmc8XBXzy4Y
license: GPL-3
maintainer: John Millikin <jmillikin@gmail.com>
stability: experimental
homepage: https://john-millikin.com/software/haskell-xmpp/
synopsis: Client library for the XMPP protocol.
category: Network
author: John Millikin <jmillikin@gmail.com>, Stephan Maka <stephan@spaceboyz.net>
exposed: True
indefinite: False
exposed-modules:
    Network.Protocol.XMPP
hidden-modules: Network.Protocol.XMPP.Client
                Network.Protocol.XMPP.Client.Authentication
                Network.Protocol.XMPP.Client.Features
                Network.Protocol.XMPP.Component Network.Protocol.XMPP.Connections
                Network.Protocol.XMPP.ErrorT Network.Protocol.XMPP.Handle
                Network.Protocol.XMPP.JID Network.Protocol.XMPP.Monad
                Network.Protocol.XMPP.Stanza Network.Protocol.XMPP.XML
abi: 97c47dc36ea38ed5a3af6e037a10fd3e
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/network-protocol-xmpp-0.4.8
library-dirs: /usr/lib/ghc-8.2.2/site-local/network-protocol-xmpp-0.4.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/network-protocol-xmpp-0.4.8
hs-libraries: HSnetwork-protocol-xmpp-0.4.8-9LXhpkDE0sYCmc8XBXzy4Y
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    gnuidn-0.2.2-BzrrzGi9rBgLNeehdjt0SF
    gnutls-0.2-JbgeHpxEtznGCBhXpkk85D
    gsasl-0.3.6-8RH9m0vfsQBIXIAyktLxXp
    libxml-sax-0.7.5-CZNJ7yMYetWDObZtx2BxlB
    monads-tf-0.1.0.3-1scKDck1nyF3hHYXqW7mNz
    network-2.6.3.2-Elf6Dxkfz0iKjb1zv5eBTP
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj transformers-0.5.2.0
    xml-types-0.3.6-8U94ZZax169GYLVDpT1mig
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             gnuidn-0.2.2-BzrrzGi9rBgLNeehdjt0SF=c6ae0a15f40e93af775be82bdb55067a
             gnutls-0.2-JbgeHpxEtznGCBhXpkk85D=f6dce36dd38029cbdc2dac594994336f
             gsasl-0.3.6-8RH9m0vfsQBIXIAyktLxXp=89a4a7f1de7e3aea8f863701557a57b1
             libxml-sax-0.7.5-CZNJ7yMYetWDObZtx2BxlB=645c9673eadf15561f992fe95c64419d
             monads-tf-0.1.0.3-1scKDck1nyF3hHYXqW7mNz=6108907d7e5c25d6f7804e9d60f9e7ed
             network-2.6.3.2-Elf6Dxkfz0iKjb1zv5eBTP=be5c9ce6f97dd4968397992ca4f22add
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=0c99dc42f18da90e6080c205f57d188a
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             xml-types-0.3.6-8U94ZZax169GYLVDpT1mig=66a00e6b1ab0a96693d6da0f27af76bf
haddock-interfaces: /usr/share/doc/haskell-network-protocol-xmpp/html/network-protocol-xmpp.haddock
haddock-html: /usr/share/doc/haskell-network-protocol-xmpp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-protocol-xmpp-0.4.8-26-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-network-protocol-xmpp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-protocol-xmpp
version: 0.4.8
id: network-protocol-xmpp-0.4.8-G78H101daLd9gypC13qbAw
key: network-protocol-xmpp-0.4.8-G78H101daLd9gypC13qbAw
license: GPL-3
maintainer: John Millikin <jmillikin@gmail.com>
stability: experimental
homepage: https://john-millikin.com/software/haskell-xmpp/
synopsis: Client library for the XMPP protocol.
category: Network
author: John Millikin <jmillikin@gmail.com>, Stephan Maka <stephan@spaceboyz.net>
exposed: True
indefinite: False
exposed-modules:
    Network.Protocol.XMPP
hidden-modules: Network.Protocol.XMPP.Client
                Network.Protocol.XMPP.Client.Authentication
                Network.Protocol.XMPP.Client.Features
                Network.Protocol.XMPP.Component Network.Protocol.XMPP.Connections
                Network.Protocol.XMPP.ErrorT Network.Protocol.XMPP.Handle
                Network.Protocol.XMPP.JID Network.Protocol.XMPP.Monad
                Network.Protocol.XMPP.Stanza Network.Protocol.XMPP.XML
abi: 04db409fc6200debc11f434666910914
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/network-protocol-xmpp-0.4.8
library-dirs: /usr/lib/ghc-8.2.2/site-local/network-protocol-xmpp-0.4.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/network-protocol-xmpp-0.4.8
hs-libraries: HSnetwork-protocol-xmpp-0.4.8-G78H101daLd9gypC13qbAw
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    gnuidn-0.2.2-3Asbckfml6kC0QtQ3vZ80Y
    gnutls-0.2-JbgeHpxEtznGCBhXpkk85D
    gsasl-0.3.6-8RH9m0vfsQBIXIAyktLxXp
    libxml-sax-0.7.5-FejhMvuTvxT64dOEVQOQrU
    monads-tf-0.1.0.3-1scKDck1nyF3hHYXqW7mNz
    network-2.6.3.4-8L4uSVu9H2RKc9gFtidscN
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj transformers-0.5.2.0
    xml-types-0.3.6-8WPJEemJnrZwepJreraPY
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             gnuidn-0.2.2-3Asbckfml6kC0QtQ3vZ80Y=b5baca0abaafa7ad14bd75e1cf057349
             gnutls-0.2-JbgeHpxEtznGCBhXpkk85D=f6dce36dd38029cbdc2dac594994336f
             gsasl-0.3.6-8RH9m0vfsQBIXIAyktLxXp=89a4a7f1de7e3aea8f863701557a57b1
             libxml-sax-0.7.5-FejhMvuTvxT64dOEVQOQrU=7bf5d226f2215e913eac1b9852a4b6f7
             monads-tf-0.1.0.3-1scKDck1nyF3hHYXqW7mNz=6108907d7e5c25d6f7804e9d60f9e7ed
             network-2.6.3.4-8L4uSVu9H2RKc9gFtidscN=ea581c47f7afb58d7ebae83854dc6afa
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             xml-types-0.3.6-8WPJEemJnrZwepJreraPY=7e7faac838649cb4151c9d4e8edfc9dc
haddock-interfaces: /usr/share/doc/haskell-network-protocol-xmpp/html/network-protocol-xmpp.haddock
haddock-html: /usr/share/doc/haskell-network-protocol-xmpp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
